summaryrefslogtreecommitdiffstats
path: root/src/compositor/compositor_api/qwaylandsurface.cpp
diff options
context:
space:
mode:
authorJohan Klokkhammer Helsing <johan.helsing@qt.io>2016-10-06 15:01:35 +0200
committerPaul Olav Tvete <paul.tvete@qt.io>2016-10-07 12:01:42 +0000
commit4a792b169ed3810d60ddb5f8fab576368fbd7c4f (patch)
treec76bc5c1a4d2f119d7f24c1944849d9f699aff61 /src/compositor/compositor_api/qwaylandsurface.cpp
parent985bd824ef70ea23484f70718b0f944533c4d076 (diff)
Rename QWaylandSurface::throttlingView to primaryView
And make sure QWaylandWlShellIntegration and QWaylandXdgShellV5Integration only send configure events if they have the primary view. Also add a convenience, QWaylandView::isPrimary. Change-Id: Ib3a9615f46c8c43897c7fac22f832d2581190c0a Reviewed-by: Paul Olav Tvete <paul.tvete@qt.io>
Diffstat (limited to 'src/compositor/compositor_api/qwaylandsurface.cpp')
-rw-r--r--src/compositor/compositor_api/qwaylandsurface.cpp17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/compositor/compositor_api/qwaylandsurface.cpp b/src/compositor/compositor_api/qwaylandsurface.cpp
index 69d182812..80e8715ea 100644
--- a/src/compositor/compositor_api/qwaylandsurface.cpp
+++ b/src/compositor/compositor_api/qwaylandsurface.cpp
@@ -690,11 +690,11 @@ void QWaylandSurface::updateSelection()
}
/*!
* Returns this QWaylandSurface's throttling view.
*
- * \sa QWaylandView::advance()
+ * \sa QWaylandView::advance(), QWaylandSurface::setPrimaryView()
*/
-QWaylandView *QWaylandSurface::throttlingView() const
+QWaylandView *QWaylandSurface::primaryView() const
{
Q_D(const QWaylandSurface);
if (d->views.isEmpty())
@@ -703,15 +703,20 @@ QWaylandView *QWaylandSurface::throttlingView() const
}
/*!
* Sets this QWaylandSurface's throttling view to \a view, in case there are
* multiple views of this surface. The throttling view is the view that
* governs the client's refresh rate. It takes care of discarding buffer
* references when QWaylandView::advance() is called. See the documentation
* for QWaylandView::advance() for more details.
*
+ * In shell surface integrations, such as QWaylandWlShellIntegration and
+ * QWaylandXdgShellV5Integration, maximize and fullscreen requests from the
+ * client will only have an effect if the integration has the primary view
+ * of the surface.
+ *
* \sa QWaylandView::advance()
*/
-void QWaylandSurface::setThrottlingView(QWaylandView *view)
+void QWaylandSurface::setPrimaryView(QWaylandView *view)
{
Q_D(QWaylandSurface);
@@ -690,11 +690,11 @@ void QWaylandSurface::updateSelection()
}
/*!
- * Returns this QWaylandSurface's throttling view.
+ * Returns this QWaylandSurface's primary view.
*
@@ -703,15 +703,20 @@ QWaylandView *QWaylandSurface::throttlingView() const
}
/*!
- * Sets this QWaylandSurface's throttling view to \a view, in case there are
- * multiple views of this surface. The throttling view is the view that
+ * Sets this QWaylandSurface's primary view to \a view, in case there are
+ * multiple views of this surface. The primary view is the view that
* governs the client's refresh rate. It takes care of discarding buffer
* references when QWaylandView::advance() is called. See the documentation